@@ -3,3 +3,5 @@ from . import client
 from .control import *
 from .convert import *
 from .client import set_config, GameBoxConfig, start_game
+from . import gadgets
+from . import formats
\ No newline at end of file
